function [ A, W, H, sigmaNoise, S, seedW, seedH ] = oracleInit( dataDir, Ls, wlen, K, mixMatFile, seedW, seedH )
%==========================================================================
% Oracle initialization
%
% S. Leglaive, R. Badeau, G. Richard, "Multichannel Audio Source Separation: Variational Inference of
% Time-Frequency Sources from Time-Domain Observations", IEEE International Conference on
% Acoustics Speech and Signal Processing (ICASSP), 2017.

% Simon LEGLAIVE, Télécom ParisTech, 2016
%==========================================================================

if nargin < 5
    mixMatFile = 'mix_filters.mat';
end
if nargin < 7
    seedW = [];
end
if nargin < 8
    seedH = [];
end

st = load(fullfile(dataDir, mixMatFile));
a = st.A;
J = size(a,2);
La = size(a,3);
W = cell(J,1);
H = cell(J,1);

A = a;

for j=1:J

    wavFile = fullfile(dataDir,['src' num2str(j) '.wav']);
    [s, fs] = audioread(wavFile);
    s = s(1:Ls);
    S(:,:,j) = mdct_multi(s,wlen,0);
    if ~isempty(seedW)
        rng(seedW);
    else
        seedW = rng;
    end
    W_init = abs(randn(size(S(:,:,j),1),K));
    if ~isempty(seedH)
        rng(seedH);
    else
        seedH = rng;
    end
    H_init = abs(randn(K,size(S(:,:,j),2)));
    [W{j}, H{j}, E] = nmf_is(abs(S(:,:,j)).^2 + eps, W_init, H_init, 500);

end

wavFile = fullfile(dataDir,'mix.wav');
[x, fs] = audioread(wavFile);
T = Ls + La - 1;
x = x(1:T,:);
sigmaNoise = sum(abs(x).^2,1)/T;

end
